%bcond_without check

Summary:        Extremely fast Python linter and code formatter
Name:           ruff
Version:        0.2.2
Release:        1%{?dist}
License:        MIT AND 0BSD AND Apache-2.0 AND BSD-2-Clause-Views AND CC0-1.0 AND ISC AND MPL-2.0 AND PSD-2.0 AND Unicode-DFS-2016 AND WTFPL AND (Apache-2.0 OR BSD-2-Clause) AND (Apache-2.0 OR BSL-1.0) AND (Apache-2.0 OR MIT) AND (Apache-2.0 WITH LLVM-exception OR Apache-2.0 OR MIT) AND (BSD-2-Clause OR Apache-2.0 OR MIT) AND (MIT OR Apache-2.0 OR Zlib) AND (MIT OR BSD-3-Clause) AND (Unlicense OR MIT)
URL:            https://github.com/astral-sh/ruff
Source0:        %{url}/archive/v%{version}/ruff-%{version}.tar.gz
#   cargo vendor --versioned-dirs && tar jcf ../%%{name}-%%{version}-vendor.tar.xz vendor/
Source1:        %{name}-%{version}-vendor.tar.bz2

# * drop Windows-specific dependencies
Patch3000:      0001-drop-Windows-specific-dependencies.patch
# * drop unavailable compile-time diagnostics feature for UUIDs
Patch3001:      0002-drop-unavailable-features-from-uuid-dependency.patch
# * drop unavailable custom memory allocators
Patch3002:      0003-remove-unavailable-custom-allocators.patch
# * do not strip debuginfo from the built executable
Patch3003:      0004-do-not-strip-debuginfo-from-built-binary-executable.patch
# * temporarily downgrade pyproject-toml dependency from 0.9 to 0.8.1
Patch3004:      0005-temporarily-downgrade-pyproject-toml-dependnecy-from1.patch

BuildRequires:  rust-toolset python3-devel python3-toml python3-pip
BuildRequires:  python3-setuptools python3-wheel python3-hatchling maturin

%description
An extremely fast Python linter and code formatter, written in Rust.
Ruff aims to be orders of magnitude faster than alternative tools while integrating 
more functionality behind a single, common interface.

Ruff can be used to replace Flake8 (plus dozens of plugins), Black, isort, pydocstyle, 
pyupgrade, autoflake, and more, all while executing tens or hundreds of times faster 
than any individual tool.

%prep
%autosetup -n ruff-%{version} -p1
%cargo_prep -V 1
# drop unused subprojects
rm -rv crates/ruff_benchmark
rm -rv crates/ruff_wasm

%build
export RUSTFLAGS="%{build_rustflags}"
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files ruff

# generate and install shell completions
target/release/ruff --generate-shell-completion bash > ruff.bash
target/release/ruff --generate-shell-completion fish > ruff.fish
target/release/ruff --generate-shell-completion zsh > _ruff

install -Dpm 0644 ruff.bash -t %{buildroot}/%{bash_completions_dir}
install -Dpm 0644 ruff.fish -t %{buildroot}/%{fish_completions_dir}
install -Dpm 0644 _ruff -t %{buildroot}/%{zsh_completions_dir}

%if %{with check}
%check
# ignore false positive snapshot test failures
export INSTA_UPDATE=always
# reduce peak memory usage
%cargo_test -- -- --test-threads 2
%endif

%files -f %{pyproject_files}
%license LICENSE
%doc README.md BREAKING_CHANGES.md
%doc CODE_OF_CONDUCT.md CONTRIBUTING.md
%{_bindir}/ruff
%{bash_completions_dir}/ruff.bash
%{fish_completions_dir}/ruff.fish
%{zsh_completions_dir}/_ruff
%{python3_sitearch}/ruff
%{python3_sitearch}/ruff*.dist-info/

%changelog
* Tue Mar 19 2024 Wang Guodong <gordonwwang@tencent.com> - 0.2.2-1
- initial build
